certification

package
v0.0.0-...-38ced02 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2026 License: MIT Imports: 22 Imported by: 0

Documentation

Index

Constants

const ReportSchemaVersion = 1

Variables

This section is empty.

Functions

func AcceptanceSmoke

func AcceptanceSmoke(output io.Writer, frameworkVersion string) error

AcceptanceSmoke makes the relationship between certification and the existing acceptance matrix explicit for callers and release evidence.

Types

type CheckResult

type CheckResult struct {
	Name       string `json:"name"`
	Status     Status `json:"status"`
	DurationMS int64  `json:"duration_ms"`
	Detail     string `json:"detail,omitempty"`
	Output     string `json:"output,omitempty"`
}

type Host

type Host struct {
	OS        string `json:"os"`
	Arch      string `json:"arch"`
	GoVersion string `json:"go_version"`
}

type Mode

type Mode string
const (
	ModeStatic Mode = "static"
	ModeReal   Mode = "real"
)

type Options

type Options struct {
	Mode             Mode
	WorkDir          string
	Keep             bool
	JSON             bool
	Output           io.Writer
	FrameworkVersion string
	RequireReal      bool
	CommandTimeout   time.Duration
}

type Prerequisite

type Prerequisite struct {
	Name     string `json:"name"`
	Command  string `json:"command"`
	Required bool   `json:"required"`
	Status   Status `json:"status"`
	Version  string `json:"version,omitempty"`
	Detail   string `json:"detail,omitempty"`
}

type PresetResult

type PresetResult struct {
	Preset     string        `json:"preset"`
	Status     Status        `json:"status"`
	ProjectDir string        `json:"project_dir,omitempty"`
	Checks     []CheckResult `json:"checks"`
	DurationMS int64         `json:"duration_ms"`
	Error      string        `json:"error,omitempty"`
}

type Report

type Report struct {
	SchemaVersion int            `json:"schema_version"`
	GeneratedAt   time.Time      `json:"generated_at"`
	Mode          Mode           `json:"mode"`
	Host          Host           `json:"host"`
	Prerequisites []Prerequisite `json:"prerequisites"`
	Presets       []PresetResult `json:"presets"`
	Passed        int            `json:"passed"`
	Failed        int            `json:"failed"`
	Blocked       int            `json:"blocked"`
	Skipped       int            `json:"skipped"`
	DurationMS    int64          `json:"duration_ms"`
	WorkDir       string         `json:"work_dir,omitempty"`
}

func Run

func Run(options Options) (Report, error)

type Status

type Status string
const (
	StatusPass    Status = "pass"
	StatusFail    Status = "fail"
	StatusBlocked Status = "blocked"
	StatusSkipped Status = "skipped"
)

Jump to